@@ -320,8 +320,7 @@ gkd_secret_item_skeleton_set_property_dbus (GDBusConnection *connection,
 	}
 
 	if (g_strcmp0 (property_name, "Attributes") == 0) {
-		gkd_exported_item_set_attributes (GKD_EXPORTED_ITEM (self),
-						  g_variant_get_variant (value));
+		gkd_exported_item_set_attributes (GKD_EXPORTED_ITEM (self), value);
 	} else if (g_strcmp0 (property_name, "Label") == 0) {
 		gkd_exported_item_set_label (GKD_EXPORTED_ITEM (self),
 					     g_variant_get_string (value, NULL));
@@ -410,36 +409,6 @@ G_DEFINE_TYPE (GkdSecretObjects, gkd_secret_objects, G_TYPE_OBJECT);
  * INTERNAL
  */
 
-static gboolean
-parse_object_path (GkdSecretObjects *self, const gchar *path, gchar **collection, gchar **item)
-{
-	const gchar *replace;
-
-	g_assert (self);
-	g_assert (path);
-	g_assert (collection);
-
-	if (!gkd_secret_util_parse_path (path, collection, item))
-		return FALSE;
-
-	if (g_str_has_prefix (path, SECRET_ALIAS_PREFIX)) {
-		replace = gkd_secret_service_get_alias (self->service, *collection);
-		if (!replace) {
-			g_free (*collection);
-			*collection = NULL;
-			if (item) {
-				g_free (*item);
-				*item = NULL;
-			}
-			return FALSE;
-		}
-		g_free (*collection);
-		*collection = g_strdup (replace);
-	}
-
-	return TRUE;
-}
-
 static GckObject *
 secret_objects_lookup_gck_object_for_path (GkdSecretObjects *self,
 					   const gchar *sender,
@@ -456,7 +425,7 @@ secret_objects_lookup_gck_object_for_path (GkdSecretObjects *self,
 
 	g_return_val_if_fail (path, FALSE);
 
-	if (!parse_object_path (self, path, &c_ident, &i_ident) || !c_ident)
+	if (!gkd_secret_util_parse_path (path, &c_ident, &i_ident) || !c_ident)
 		goto out;
 
 	/* The session we're using to access the object */
@@ -845,7 +814,7 @@ collection_method_create_item (GkdExportedCollection *skeleton,
 		goto cleanup;
 	}
 
-	if (!parse_object_path (self, base, &identifier, NULL))
+	if (!gkd_secret_util_parse_path (base, &identifier, NULL))
 		g_return_val_if_reached (FALSE);
 	g_return_val_if_fail (identifier, FALSE);
 
@@ -995,17 +964,6 @@ gkd_secret_objects_dispose (GObject *obj)
 	G_OBJECT_CLASS (gkd_secret_objects_parent_class)->dispose (obj);
 }
 
-static void
-gkd_secret_objects_finalize (GObject *obj)
-{
-	GkdSecretObjects *self = GKD_SECRET_OBJECTS (obj);
-
-	g_assert (!self->pkcs11_slot);
-	g_assert (!self->service);
-
-	G_OBJECT_CLASS (gkd_secret_objects_parent_class)->finalize (obj);
-}
-
 static void
 gkd_secret_objects_set_property (GObject *obj, guint prop_id, const GValue *value,
 				 GParamSpec *pspec)
@@ -1056,7 +1014,6 @@ gkd_secret_objects_class_init (GkdSecretObjectsClass *klass)
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
 	gobject_class->dispose = gkd_secret_objects_dispose;
-	gobject_class->finalize = gkd_secret_objects_finalize;
 	gobject_class->set_property = gkd_secret_objects_set_property;
 	gobject_class->get_property = gkd_secret_objects_get_property;
 
@@ -1094,7 +1051,7 @@ gkd_secret_objects_lookup_collection (GkdSecretObjects *self, const gchar *calle
 	g_return_val_if_fail (GKD_SECRET_IS_OBJECTS (self), NULL);
 	g_return_val_if_fail (path, NULL);
 
-	if (!parse_object_path (self, path, &identifier, NULL))
+	if (!gkd_secret_util_parse_path (path, &identifier, NULL))
 		return NULL;
 
 	/* The session we're using to access the object */
@@ -1139,7 +1096,7 @@ gkd_secret_objects_lookup_item (GkdSecretObjects *self, const gchar *caller,
 	g_return_val_if_fail (caller, NULL);
 	g_return_val_if_fail (path, NULL);
 
-	if (!parse_object_path (self, path, &collection, &identifier))
+	if (!gkd_secret_util_parse_path (path, &collection, &identifier))
 		return NULL;
 
 	/* The session we're using to access the object */
@@ -1208,7 +1165,7 @@ gkd_secret_objects_foreach_item (GkdSecretObjects *self,
 		session = gkd_secret_service_get_pkcs11_session (self->service, caller);
 	}
 
-	if (!parse_object_path (self, base, &identifier, NULL))
+	if (!gkd_secret_util_parse_path (base, &identifier, NULL))
 		g_return_if_reached ();
 
 	gck_builder_add_ulong (&builder, CKA_CLASS, CKO_SECRET_KEY);
@@ -1263,7 +1220,6 @@ gkd_secret_objects_foreach_collection (GkdSecretObjects *self,
 	}
 
 	for (l = collections; l; l = g_list_next (l)) {
-
 		identifier = gck_object_get_data (l->data, CKA_ID, NULL, &n_identifier, &error);
 		if (identifier == NULL) {
 			g_warning ("couldn't get collection identifier: %s", egg_error_message (error));
@@ -1323,7 +1279,7 @@ gkd_secret_objects_handle_search_items (GkdSecretObjects *self,
 	}
 
 	if (base != NULL) {
-		if (!parse_object_path (self, base, &identifier, NULL))
+		if (!gkd_secret_util_parse_path (base, &identifier, NULL))
 			g_return_val_if_reached (FALSE);
 		gck_builder_add_string (&builder, CKA_G_COLLECTION, identifier);
 		g_free (identifier);
@@ -1532,7 +1488,7 @@ gkd_secret_objects_register_item (GkdSecretObjects *self,
 
 	skeleton = g_hash_table_lookup (self->items_to_skeletons, item_path);
 	if (skeleton != NULL) {
-		g_warning ("asked to register item %p, but it's already registered", item_path);
+		g_warning ("asked to register item %s, but it's already registered", item_path);
 		return;
 	}
 
@@ -1560,7 +1516,7 @@ gkd_secret_objects_unregister_item (GkdSecretObjects *self,
 				    const gchar *item_path)
 {
 	if (!g_hash_table_remove (self->items_to_skeletons, item_path)) {
-		g_warning ("asked to unregister item %p, but it wasn't found", item_path);
+		g_warning ("asked to unregister item %s, but it wasn't found", item_path);
 		return;
 	}
 }
@@ -1664,7 +1620,7 @@ gkd_secret_objects_register_collection (GkdSecretObjects *self,
 
 	skeleton = g_hash_table_lookup (self->collections_to_skeletons, collection_path);
 	if (skeleton != NULL) {
-		g_warning ("asked to register collection %p, but it's already registered", collection_path);
+		g_warning ("asked to register collection %s, but it's already registered", collection_path);
 		return;
 	}
 
@@ -1694,7 +1650,7 @@ gkd_secret_objects_unregister_collection (GkdSecretObjects *self,
 					  const gchar *collection_path)
 {
 	if (!g_hash_table_remove (self->collections_to_skeletons, collection_path)) {
-		g_warning ("asked to unregister collection %p, but it wasn't found", collection_path);
+		g_warning ("asked to unregister collection %s, but it wasn't found", collection_path);
 		return;
 	}
 }
