@@ -20,6 +20,7 @@
 
 #include "config.h"
 
+#include "gkd-dbus.h"
 #include "gkd-secret-dispatch.h"
 #include "gkd-secret-error.h"
 #include "gkd-secret-exchange.h"
@@ -71,8 +72,13 @@ emit_completed (GkdSecretPrompt *self, gboolean dismissed)
 	g_return_if_fail (GKD_SECRET_PROMPT_GET_CLASS (self)->encode_result);
 	variant = GKD_SECRET_PROMPT_GET_CLASS (self)->encode_result (self);
 
-	gkd_exported_prompt_emit_completed (self->pv->skeleton,
-					    dismissed, variant);
+	/* Emit signal manually, so that we can set the caller as destination */
+	g_dbus_connection_emit_signal (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (self->pv->skeleton)),
+				       self->pv->caller,
+				       g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (self->pv->skeleton)),
+				       "org.freedesktop.Secret.Prompt", "Completed",
+				       g_variant_new ("(b@v)", dismissed, variant),
+				       NULL);
 }
 
 static void
@@ -103,6 +109,9 @@ prompt_method_prompt (GkdExportedPrompt *skeleton,
 		      gchar *window_id,
 		      GkdSecretPrompt *self)
 {
+	if (!gkd_dbus_invocation_matches_caller (invocation, self->pv->caller))
+		return FALSE;
+
 	/* Act as if this object no longer exists */
 	if (self->pv->completed)
 		return FALSE;
@@ -131,6 +140,9 @@ prompt_method_dismiss (GkdExportedPrompt *skeleton,
 		       GDBusMethodInvocation *invocation,
 		       GkdSecretPrompt *self)
 {
+	if (!gkd_dbus_invocation_matches_caller (invocation, self->pv->caller))
+		return FALSE;
+
 	/* Act as if this object no longer exists */
 	if (self->pv->completed)
 		return FALSE;
